@@ -6,8 +6,7 @@ use crate::stream::Stream;
 use crate::task::{Context, Poll};
 
 pin_project! {
-    #[doc(hidden)]
-    #[allow(missing_debug_implementations)]
+    #[derive(Debug)]
     pub struct Enumerate<S> {
         #[pin]
         stream: S,
@@ -17,7 +16,7 @@ pin_project! {
 
 impl<S> Enumerate<S> {
     pub(super) fn new(stream: S) -> Self {
-        Enumerate { stream, i: 0 }
+        Self { stream, i: 0 }
     }
 }
 
