@@ -1,8 +1,8 @@
+use std::future::Future;
 use std::pin::Pin;
 
 use pin_project_lite::pin_project;
 
-use crate::future::Future;
 use crate::stream::Stream;
 use crate::task::{Context, Poll};
 
@@ -18,7 +18,7 @@ pin_project! {
 
 impl<S, T> LastFuture<S, T> {
     pub(crate) fn new(stream: S) -> Self {
-        LastFuture { stream, last: None }
+        Self { stream, last: None }
     }
 }
 
