@@ -1,10 +1,10 @@
 use std::cmp::Ordering;
 use std::pin::Pin;
+use std::future::Future;
 
 use pin_project_lite::pin_project;
 
 use super::partial_cmp::PartialCmpFuture;
-use crate::future::Future;
 use crate::prelude::*;
 use crate::stream::Stream;
 use crate::task::{Context, Poll};
@@ -25,7 +25,7 @@ where
     L::Item: PartialOrd<R::Item>,
 {
     pub(super) fn new(l: L, r: R) -> Self {
-        LeFuture {
+        Self {
             partial_cmp: l.partial_cmp(r),
         }
     }
