@@ -1,9 +1,9 @@
 use std::cmp::Ordering;
 use std::pin::Pin;
+use std::future::Future;
 
 use pin_project_lite::pin_project;
 
-use crate::future::Future;
 use crate::stream::Stream;
 use crate::task::{Context, Poll};
 
@@ -20,7 +20,7 @@ pin_project! {
 
 impl<S, F, T> MinByFuture<S, F, T> {
     pub(super) fn new(stream: S, compare: F) -> Self {
-        MinByFuture {
+        Self {
             stream,
             compare,
             min: None,
