@@ -44,6 +44,7 @@ mod last;
 mod le;
 mod lt;
 mod map;
+mod max;
 mod max_by;
 mod max_by_key;
 mod min;
@@ -80,6 +81,7 @@ use gt::GtFuture;
 use last::LastFuture;
 use le::LeFuture;
 use lt::LtFuture;
+use max::MaxFuture;
 use max_by::MaxByFuture;
 use max_by_key::MaxByKeyFuture;
 use min::MinFuture;
@@ -109,25 +111,36 @@ pub use take_while::TakeWhile;
 pub use zip::Zip;
 
 use std::cmp::Ordering;
-use std::marker::PhantomData;
 
 cfg_unstable! {
+    use std::future::Future;
     use std::pin::Pin;
     use std::time::Duration;
 
-    use crate::future::Future;
     use crate::stream::into_stream::IntoStream;
     use crate::stream::{FromStream, Product, Sum};
+    use crate::stream::Extend;
+
+    use count::CountFuture;
+    use partition::PartitionFuture;
+    use unzip::UnzipFuture;
 
     pub use merge::Merge;
     pub use flatten::Flatten;
     pub use flat_map::FlatMap;
     pub use timeout::{TimeoutError, Timeout};
+    pub use throttle::Throttle;
+    pub use delay::Delay;
 
+    mod count;
     mod merge;
     mod flatten;
     mod flat_map;
+    mod partition;
     mod timeout;
+    mod throttle;
+    mod delay;
+    mod unzip;
 }
 
 extension_trait! {
@@ -151,7 +164,7 @@ extension_trait! {
 
         [`std::iter::Iterator`]: https://doc.rust-lang.org/std/iter/trait.Iterator.html
         [`futures::stream::Stream`]:
-        https://docs.rs/futures-preview/0.3.0-alpha.17/futures/stream/trait.Stream.html
+        https://docs.rs/futures/0.3/futures/stream/trait.Stream.html
         [provided methods]: #provided-methods
         [`StreamExt`]: ../prelude/trait.StreamExt.html
         [prelude]: ../prelude/index.html
@@ -278,16 +291,14 @@ extension_trait! {
         where
             Self: Sized,
         {
-            Take {
-                stream: self,
-                remaining: n,
-            }
+            Take::new(self, n)
         }
 
         #[doc = r#"
             Creates a stream that yields elements based on a predicate.
 
             # Examples
+
             ```
             # fn main() { async_std::task::block_on(async {
             #
@@ -300,11 +311,11 @@ extension_trait! {
             assert_eq!(s.next().await, Some(1));
             assert_eq!(s.next().await, Some(2));
             assert_eq!(s.next().await, None);
-
             #
             # }) }
+            ```
         "#]
-        fn take_while<P>(self, predicate: P) -> TakeWhile<Self, P, Self::Item>
+        fn take_while<P>(self, predicate: P) -> TakeWhile<Self, P>
         where
             Self: Sized,
             P: FnMut(&Self::Item) -> bool,
@@ -312,6 +323,47 @@ extension_trait! {
             TakeWhile::new(self, predicate)
         }
 
+        #[doc = r#"
+            Limit the amount of items yielded per timeslice in a stream.
+
+            This stream does not drop any items, but will only limit the rate at which items pass through.
+            # Examples
+            ```
+            # fn main() { async_std::task::block_on(async {
+            #
+            use async_std::prelude::*;
+            use async_std::stream;
+            use std::time::{Duration, Instant};
+
+            let start = Instant::now();
+
+            // emit value every 5 milliseconds
+            let s = stream::interval(Duration::from_millis(5)).take(2);
+
+            // throttle for 10 milliseconds
+            let mut s = s.throttle(Duration::from_millis(10));
+
+            s.next().await;
+            assert!(start.elapsed().as_millis() >= 5);
+
+            s.next().await;
+            assert!(start.elapsed().as_millis() >= 15);
+
+            s.next().await;
+            assert!(start.elapsed().as_millis() >= 35);
+            #
+            # }) }
+            ```
+        "#]
+        #[cfg(all(feature = "default", feature = "unstable"))]
+        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
+        fn throttle(self, d: Duration) -> Throttle<Self>
+        where
+            Self: Sized,
+        {
+            Throttle::new(self, d)
+        }
+
         #[doc = r#"
             Creates a stream that yields each `step`th element.
 
@@ -397,9 +449,9 @@ extension_trait! {
             use async_std::stream;
 
             let v = stream::from_iter(vec![&1, &2, &3]);
-                
+
             let mut v_cloned = v.cloned();
-            
+
             assert_eq!(v_cloned.next().await, Some(1));
             assert_eq!(v_cloned.next().await, Some(2));
             assert_eq!(v_cloned.next().await, Some(3));
@@ -409,10 +461,10 @@ extension_trait! {
             # }) }
             ```
         "#]
-        fn cloned<'a,T>(self) -> Cloned<Self>
+        fn cloned<'a, T>(self) -> Cloned<Self>
         where
             Self: Sized + Stream<Item = &'a T>,
-            T : 'a + Clone,
+            T: Clone + 'a,
         {
             Cloned::new(self)
         }
@@ -442,10 +494,10 @@ extension_trait! {
             # }) }
             ```
         "#]
-        fn copied<'a,T>(self) -> Copied<Self>
+        fn copied<'a, T>(self) -> Copied<Self>
         where
             Self: Sized + Stream<Item = &'a T>,
-            T : 'a + Copy,
+            T: Copy + 'a,
         {
             Copied::new(self)
         }
@@ -474,10 +526,9 @@ extension_trait! {
             # })
             ```
         "#]
-        fn cycle(self) -> Cycle<Self, Self::Item>
-            where
-                Self: Sized,
-                Self::Item: Clone,
+        fn cycle(self) -> Cycle<Self>
+        where
+            Self: Clone + Sized,
         {
             Cycle::new(self)
         }
@@ -504,7 +555,6 @@ extension_trait! {
             assert_eq!(s.next().await, Some((1, 'b')));
             assert_eq!(s.next().await, Some((2, 'c')));
             assert_eq!(s.next().await, None);
-
             #
             # }) }
             ```
@@ -516,6 +566,47 @@ extension_trait! {
             Enumerate::new(self)
         }
 
+        #[doc = r#"
+            Creates a stream that is delayed before it starts yielding items.
+
+            # Examples
+
+            ```
+            # fn main() { async_std::task::block_on(async {
+            #
+            use async_std::prelude::*;
+            use async_std::stream;
+            use std::time::{Duration, Instant};
+
+            let start = Instant::now();
+            let mut s = stream::from_iter(vec![0u8, 1, 2]).delay(Duration::from_millis(200));
+
+            assert_eq!(s.next().await, Some(0));
+            // The first time will take more than 200ms due to delay.
+            assert!(start.elapsed().as_millis() >= 200);
+
+            assert_eq!(s.next().await, Some(1));
+            // There will be no delay after the first time.
+            assert!(start.elapsed().as_millis() <= 210);
+
+            assert_eq!(s.next().await, Some(2));
+            assert!(start.elapsed().as_millis() <= 210);
+
+            assert_eq!(s.next().await, None);
+            assert!(start.elapsed().as_millis() <= 210);
+            #
+            # }) }
+            ```
+        "#]
+        #[cfg(any(feature = "unstable", feature = "docs"))]
+        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
+        fn delay(self, dur: std::time::Duration) -> Delay<Self>
+        where
+            Self: Sized,
+        {
+            Delay::new(self, dur)
+        }
+
         #[doc = r#"
             Takes a closure and creates a stream that calls that closure on every element of this stream.
 
@@ -539,7 +630,7 @@ extension_trait! {
             # }) }
             ```
         "#]
-        fn map<B, F>(self, f: F) -> Map<Self, F, Self::Item, B>
+        fn map<B, F>(self, f: F) -> Map<Self, F>
         where
             Self: Sized,
             F: FnMut(Self::Item) -> B,
@@ -564,17 +655,18 @@ extension_trait! {
             let s = stream::from_iter(vec![1, 2, 3, 4, 5]);
 
             let sum = s
-                    .inspect(|x| println!("about to filter {}", x))
-                    .filter(|x| x % 2 == 0)
-                    .inspect(|x| println!("made it through filter: {}", x))
-                    .fold(0, |sum, i| sum + i).await;
+               .inspect(|x| println!("about to filter {}", x))
+               .filter(|x| x % 2 == 0)
+               .inspect(|x| println!("made it through filter: {}", x))
+               .fold(0, |sum, i| sum + i)
+               .await;
 
             assert_eq!(sum, 6);
             #
             # }) }
             ```
         "#]
-        fn inspect<F>(self, f: F) -> Inspect<Self, F, Self::Item>
+        fn inspect<F>(self, f: F) -> Inspect<Self, F>
         where
             Self: Sized,
             F: FnMut(&Self::Item),
@@ -617,7 +709,6 @@ extension_trait! {
             #
             # }) }
             ```
-
         "#]
         fn last(
             self,
@@ -655,10 +746,7 @@ extension_trait! {
         where
             Self: Sized,
         {
-            Fuse {
-                stream: self,
-                done: false,
-            }
+            Fuse::new(self)
         }
 
         #[doc = r#"
@@ -684,7 +772,7 @@ extension_trait! {
             # }) }
             ```
         "#]
-        fn filter<P>(self, predicate: P) -> Filter<Self, P, Self::Item>
+        fn filter<P>(self, predicate: P) -> Filter<Self, P>
         where
             Self: Sized,
             P: FnMut(&Self::Item) -> bool,
@@ -720,7 +808,7 @@ extension_trait! {
         "#]
         #[cfg(feature = "unstable")]
         #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
-        fn flat_map<U, F>(self, f: F) -> FlatMap<Self, U, Self::Item, F>
+        fn flat_map<U, F>(self, f: F) -> FlatMap<Self, U, F>
             where
                 Self: Sized,
                 U: IntoStream,
@@ -754,7 +842,7 @@ extension_trait! {
         "#]
         #[cfg(feature = "unstable")]
         #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
-        fn flatten(self) -> Flatten<Self, Self::Item>
+        fn flatten(self) -> Flatten<Self>
         where
             Self: Sized,
             Self::Item: IntoStream,
@@ -795,7 +883,7 @@ extension_trait! {
             # }) }
             ```
         "#]
-        fn filter_map<B, F>(self, f: F) -> FilterMap<Self, F, Self::Item, B>
+        fn filter_map<B, F>(self, f: F) -> FilterMap<Self, F>
         where
             Self: Sized,
             F: FnMut(Self::Item) -> Option<B>,
@@ -803,7 +891,7 @@ extension_trait! {
             FilterMap::new(self, f)
         }
 
-         #[doc = r#"
+        #[doc = r#"
             Returns the element that gives the minimum value with respect to the
             specified key function. If several elements are equally minimum,
             the first element is returned. If the stream is empty, `None` is returned.
@@ -816,10 +904,10 @@ extension_trait! {
             use async_std::prelude::*;
             use async_std::stream;
 
-            let s = stream::from_iter(vec![1isize, 2, -3]);
+            let s = stream::from_iter(vec![-1isize, 2, -3]);
 
             let min = s.clone().min_by_key(|x| x.abs()).await;
-            assert_eq!(min, Some(1));
+            assert_eq!(min, Some(-1));
 
             let min = stream::empty::<isize>().min_by_key(|x| x.abs()).await;
             assert_eq!(min, None);
@@ -827,19 +915,19 @@ extension_trait! {
             # }) }
             ```
         "#]
-        fn min_by_key<K>(
+        fn min_by_key<B, F>(
             self,
-            key_by: K,
-        ) -> impl Future<Output = Option<Self::Item>> [MinByKeyFuture<Self, Self::Item, K>]
+            key_by: F,
+        ) -> impl Future<Output = Option<Self::Item>> [MinByKeyFuture<Self, Self::Item, F>]
         where
             Self: Sized,
-            Self::Item: Ord,
-            K: FnMut(&Self::Item) -> Self::Item,
+            B: Ord,
+            F: FnMut(&Self::Item) -> B,
         {
             MinByKeyFuture::new(self, key_by)
         }
 
-         #[doc = r#"
+        #[doc = r#"
             Returns the element that gives the maximum value with respect to the
             specified key function. If several elements are equally maximum,
             the first element is returned. If the stream is empty, `None` is returned.
@@ -852,25 +940,25 @@ extension_trait! {
             use async_std::prelude::*;
             use async_std::stream;
 
-            let s = stream::from_iter(vec![-1isize, -2, -3]);
+            let s = stream::from_iter(vec![-3_i32, 0, 1, 5, -10]);
 
             let max = s.clone().max_by_key(|x| x.abs()).await;
-            assert_eq!(max, Some(3));
+            assert_eq!(max, Some(-10));
 
-            let max = stream::empty::<isize>().min_by_key(|x| x.abs()).await;
+            let max = stream::empty::<isize>().max_by_key(|x| x.abs()).await;
             assert_eq!(max, None);
             #
             # }) }
             ```
         "#]
-        fn max_by_key<K>(
+        fn max_by_key<B, F>(
             self,
-            key_by: K,
-        ) -> impl Future<Output = Option<Self::Item>> [MaxByKeyFuture<Self, Self::Item, K>]
+            key_by: F,
+        ) -> impl Future<Output = Option<Self::Item>> [MaxByKeyFuture<Self, Self::Item, F>]
         where
             Self: Sized,
-            Self::Item: Ord,
-            K: FnMut(&Self::Item) -> Self::Item,
+            B: Ord,
+            F: FnMut(&Self::Item) -> B,
         {
             MaxByKeyFuture::new(self, key_by)
         }
@@ -914,6 +1002,39 @@ extension_trait! {
         }
 
         #[doc = r#"
+            Returns the element that gives the maximum value. If several elements are equally maximum,
+            the first element is returned. If the stream is empty, `None` is returned.
+
+            # Examples
+
+            ```ignore
+            # fn main() { async_std::task::block_on(async {
+            #
+            use async_std::prelude::*;
+            use async_std::stream;
+
+            let s = stream::from_iter(vec![1usize, 2, 3]);
+
+            let max = s.clone().max().await;
+            assert_eq!(max, Some(3));
+
+            let max = stream::empty::<usize>().max().await;
+            assert_eq!(max, None);
+            #
+            # }) }
+            ```
+        "#]
+        fn max<F>(
+            self,
+        ) -> impl Future<Output = Option<Self::Item>> [MaxFuture<Self, F, Self::Item>]
+        where
+            Self: Sized,
+            F: FnMut(&Self::Item, &Self::Item) -> Ordering,
+        {
+            MaxFuture::new(self)
+        }
+
+                #[doc = r#"
             Returns the element that gives the minimum value. If several elements are equally minimum,
             the first element is returned. If the stream is empty, `None` is returned.
 
@@ -1042,7 +1163,7 @@ extension_trait! {
             n: usize,
         ) -> impl Future<Output = Option<Self::Item>> + '_ [NthFuture<'_, Self>]
         where
-            Self: Sized,
+            Self: Unpin + Sized,
         {
             NthFuture::new(self, n)
         }
@@ -1101,12 +1222,7 @@ extension_trait! {
             Self: Unpin + Sized,
             F: FnMut(Self::Item) -> bool,
         {
-            AllFuture {
-                stream: self,
-                result: true, // the default if the empty stream
-                _marker: PhantomData,
-                f,
-            }
+            AllFuture::new(self, f)
         }
 
         #[doc = r#"
@@ -1150,9 +1266,9 @@ extension_trait! {
         fn find<P>(
             &mut self,
             p: P,
-        ) -> impl Future<Output = Option<Self::Item>> + '_ [FindFuture<'_, Self, P, Self::Item>]
+        ) -> impl Future<Output = Option<Self::Item>> + '_ [FindFuture<'_, Self, P>]
         where
-            Self: Sized,
+            Self: Unpin + Sized,
             P: FnMut(&Self::Item) -> bool,
         {
             FindFuture::new(self, p)
@@ -1178,9 +1294,9 @@ extension_trait! {
         fn find_map<F, B>(
             &mut self,
             f: F,
-        ) -> impl Future<Output = Option<B>> + '_ [FindMapFuture<'_, Self, F, Self::Item, B>]
+        ) -> impl Future<Output = Option<B>> + '_ [FindMapFuture<'_, Self, F>]
         where
-            Self: Sized,
+            Self: Unpin + Sized,
             F: FnMut(Self::Item) -> Option<B>,
         {
             FindMapFuture::new(self, f)
@@ -1212,7 +1328,7 @@ extension_trait! {
             self,
             init: B,
             f: F,
-        ) -> impl Future<Output = B> [FoldFuture<Self, F, Self::Item, B>]
+        ) -> impl Future<Output = B> [FoldFuture<Self, F, B>]
         where
             Self: Sized,
             F: FnMut(B, Self::Item) -> B,
@@ -1220,6 +1336,44 @@ extension_trait! {
             FoldFuture::new(self, init, f)
         }
 
+        #[doc = r#"
+            A combinator that applies a function to every element in a stream
+            creating two collections from it.
+
+            # Examples
+
+            Basic usage:
+
+            ```
+            # fn main() { async_std::task::block_on(async {
+            #
+            use async_std::prelude::*;
+            use async_std::stream;
+
+            let (even, odd): (Vec<i32>, Vec<i32>) = stream::from_iter(vec![1, 2, 3])
+                .partition(|&n| n % 2 == 0).await;
+
+            assert_eq!(even, vec![2]);
+            assert_eq!(odd, vec![1, 3]);
+
+            #
+            # }) }
+            ```
+        "#]
+        #[cfg(feature = "unstable")]
+        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
+        fn partition<B, F>(
+            self,
+            f: F,
+        ) -> impl Future<Output = (B, B)> [PartitionFuture<Self, F, B>]
+        where
+            Self: Sized,
+            F: FnMut(&Self::Item) -> bool,
+            B: Default + Extend<Self::Item>,
+        {
+            PartitionFuture::new(self, f)
+        }
+
         #[doc = r#"
             Call a closure on each element of the stream.
 
@@ -1247,7 +1401,7 @@ extension_trait! {
         fn for_each<F>(
             self,
             f: F,
-        ) -> impl Future<Output = ()> [ForEachFuture<Self, F, Self::Item>]
+        ) -> impl Future<Output = ()> [ForEachFuture<Self, F>]
         where
             Self: Sized,
             F: FnMut(Self::Item),
@@ -1308,12 +1462,55 @@ extension_trait! {
             Self: Unpin + Sized,
             F: FnMut(Self::Item) -> bool,
         {
-            AnyFuture {
-                stream: self,
-                result: false, // the default if the empty stream
-                _marker: PhantomData,
-                f,
-            }
+            AnyFuture::new(self, f)
+        }
+
+        #[doc = r#"
+            Borrows an stream, rather than consuming it.
+
+            This is useful to allow applying stream adaptors while still retaining ownership of the original stream.
+
+            # Examples
+
+            ```
+            # fn main() { async_std::task::block_on(async {
+            #
+            use async_std::prelude::*;
+            use async_std::stream;
+
+            let a = vec![1isize, 2, 3];
+
+            let stream = stream::from_iter(a);
+
+            let sum: isize = stream.take(5).sum().await;
+
+            assert_eq!(sum, 6);
+
+            // if we try to use stream again, it won't work. The following line
+            // gives error: use of moved value: `stream`
+            // assert_eq!(stream.next(), None);
+
+            // let's try that again
+            let a = vec![1isize, 2, 3];
+
+            let mut stream = stream::from_iter(a);
+
+            // instead, we add in a .by_ref()
+            let sum: isize = stream.by_ref().take(2).sum().await;
+
+            assert_eq!(sum, 3);
+
+            // now this is just fine:
+            assert_eq!(stream.next().await, Some(3));
+            assert_eq!(stream.next().await, None);
+            #
+            # }) }
+            ```
+        "#]
+        #[cfg(all(feature = "default", feature = "unstable"))]
+        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
+        fn by_ref(&mut self) -> &mut Self {
+            self
         }
 
         #[doc = r#"
@@ -1388,7 +1585,7 @@ extension_trait! {
             # }) }
             ```
         "#]
-        fn skip_while<P>(self, predicate: P) -> SkipWhile<Self, P, Self::Item>
+        fn skip_while<P>(self, predicate: P) -> SkipWhile<Self, P>
         where
             Self: Sized,
             P: FnMut(&Self::Item) -> bool,
@@ -1471,7 +1668,7 @@ extension_trait! {
             use async_std::prelude::*;
             use async_std::stream;
 
-            let s = stream::from_iter(vec![1usize, 2, 3]);
+            let mut s = stream::from_iter(vec![1usize, 2, 3]);
             let sum = s.try_fold(0, |acc, v| {
                 if (acc+v) % 2 == 1 {
                     Ok(v+3)
@@ -1486,12 +1683,12 @@ extension_trait! {
             ```
         "#]
         fn try_fold<B, F, T, E>(
-            self,
+            &mut self,
             init: T,
             f: F,
-        ) -> impl Future<Output = Result<T, E>> [TryFoldFuture<Self, F, T>]
+        ) -> impl Future<Output = Result<T, E>> + '_ [TryFoldFuture<'_, Self, F, T>]
         where
-            Self: Sized,
+            Self: Unpin + Sized,
             F: FnMut(B, Self::Item) -> Result<T, E>,
         {
             TryFoldFuture::new(self, init, f)
@@ -1511,7 +1708,7 @@ extension_trait! {
 
             let (tx, rx) = channel();
 
-            let s = stream::from_iter(vec![1u8, 2, 3]);
+            let mut s = stream::from_iter(vec![1u8, 2, 3]);
             let s = s.try_for_each(|v| {
                 if v % 2 == 1 {
                     tx.clone().send(v).unwrap();
@@ -1532,11 +1729,11 @@ extension_trait! {
             ```
         "#]
         fn try_for_each<F, E>(
-            self,
+            &mut self,
             f: F,
-        ) -> impl Future<Output = E> [TryForEachFuture<Self, F, Self::Item, E>]
+        ) -> impl Future<Output = E> + 'a [TryForEachFuture<'_, Self, F>]
         where
-            Self: Sized,
+            Self: Unpin + Sized,
             F: FnMut(Self::Item) -> Result<(), E>,
         {
             TryForEachFuture::new(self, f)
@@ -1581,12 +1778,50 @@ extension_trait! {
         #[inline]
         fn zip<U>(self, other: U) -> Zip<Self, U>
         where
-            Self: Sized + Stream,
+            Self: Sized,
             U: Stream,
         {
             Zip::new(self, other)
         }
 
+        #[doc = r#"
+            Converts an stream of pairs into a pair of containers.
+
+            `unzip()` consumes an entire stream of pairs, producing two collections: one from the left elements of the pairs, and one from the right elements.
+
+            This function is, in some sense, the opposite of [`zip`].
+
+            [`zip`]: trait.Stream.html#method.zip
+
+            # Example
+
+            ```
+            # fn main() { async_std::task::block_on(async {
+            #
+            use async_std::prelude::*;
+            use async_std::stream;
+
+            let s  = stream::from_iter(vec![(1,2), (3,4)]);
+
+            let (left, right): (Vec<_>, Vec<_>) = s.unzip().await;
+
+            assert_eq!(left, [1, 3]);
+            assert_eq!(right, [2, 4]);
+            #
+            # }) }
+            ```
+        "#]
+        #[cfg(feature = "unstable")]
+        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
+        fn unzip<A, B, FromA, FromB>(self) -> impl Future<Output = (FromA, FromB)> [UnzipFuture<Self, FromA, FromB>]
+        where
+        FromA: Default + Extend<A>,
+        FromB: Default + Extend<B>,
+        Self: Stream<Item = (A, B)> + Sized,
+        {
+            UnzipFuture::new(self)
+        }
+
         #[doc = r#"
             Transforms a stream into a collection.
 
@@ -1640,7 +1875,6 @@ extension_trait! {
         "#]
         #[cfg(feature = "unstable")]
         #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
-        #[must_use = "if you really need to exhaust the iterator, consider `.for_each(drop)` instead (TODO)"]
         fn collect<'a, B>(
             self,
         ) -> impl Future<Output = B> + 'a [Pin<Box<dyn Future<Output = B> + 'a>>]
@@ -1654,26 +1888,25 @@ extension_trait! {
         #[doc = r#"
             Combines multiple streams into a single stream of all their outputs.
 
-            Items are yielded as soon as they're received, and the stream continues yield until both
-            streams have been exhausted.
+            Items are yielded as soon as they're received, and the stream continues yield until
+            both streams have been exhausted. The output ordering between streams is not guaranteed.
 
             # Examples
 
             ```
             # async_std::task::block_on(async {
             use async_std::prelude::*;
-            use async_std::stream;
+            use async_std::stream::{self, FromStream};
 
             let a = stream::once(1u8);
             let b = stream::once(2u8);
             let c = stream::once(3u8);
 
-            let mut s = a.merge(b).merge(c);
+            let s = a.merge(b).merge(c);
+            let mut lst = Vec::from_stream(s).await;
 
-            assert_eq!(s.next().await, Some(1u8));
-            assert_eq!(s.next().await, Some(2u8));
-            assert_eq!(s.next().await, Some(3u8));
-            assert_eq!(s.next().await, None);
+            lst.sort_unstable();
+            assert_eq!(&lst, &[1u8, 2u8, 3u8]);
             # });
             ```
         "#]
@@ -1739,28 +1972,28 @@ extension_trait! {
             use async_std::stream;
 
             let s = stream::from_iter(vec![1usize, 2, 3]);
-            let res = s.clone().position(|x| *x == 1).await;
+            let res = s.clone().position(|x| x == 1).await;
             assert_eq!(res, Some(0));
 
-            let res = s.clone().position(|x| *x == 2).await;
+            let res = s.clone().position(|x| x == 2).await;
             assert_eq!(res, Some(1));
 
-            let res = s.clone().position(|x| *x == 3).await;
+            let res = s.clone().position(|x| x == 3).await;
             assert_eq!(res, Some(2));
 
-            let res = s.clone().position(|x| *x == 4).await;
+            let res = s.clone().position(|x| x == 4).await;
             assert_eq!(res, None);
             #
             # }) }
             ```
         "#]
         fn position<P>(
-           self,
-           predicate: P
-        ) -> impl Future<Output = Option<usize>>  [PositionFuture<Self, P>]
+           &mut self,
+           predicate: P,
+        ) -> impl Future<Output = Option<usize>> + '_ [PositionFuture<'_, Self, P>]
         where
-            Self: Sized,
-            P: FnMut(&Self::Item) -> bool,
+            Self: Unpin + Sized,
+            P: FnMut(Self::Item) -> bool,
         {
             PositionFuture::new(self, predicate)
         }
@@ -1804,10 +2037,41 @@ extension_trait! {
             CmpFuture::new(self, other)
         }
 
-           #[doc = r#"
+        #[doc = r#"
+            Counts the number of elements in the stream.
+
+            # Examples
+
+            ```
+            # fn main() { async_std::task::block_on(async {
+            #
+            use async_std::prelude::*;
+            use async_std::stream;
+
+            let s1 = stream::from_iter(vec![0]);
+            let s2 = stream::from_iter(vec![1, 2, 3]);
+
+            assert_eq!(s1.count().await, 1);
+            assert_eq!(s2.count().await, 3);
+            #
+            # }) }
+            ```
+        "#]
+        #[cfg(feature = "unstable")]
+        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
+        fn count(self) -> impl Future<Output = usize> [CountFuture<Self>]
+        where
+            Self: Sized,
+        {
+            CountFuture::new(self)
+        }
+
+        #[doc = r#"
             Determines if the elements of this `Stream` are lexicographically
             not equal to those of another.
+
             # Examples
+
             ```
             # fn main() { async_std::task::block_on(async {
             #
@@ -1832,7 +2096,7 @@ extension_trait! {
            other: S
         ) -> impl Future<Output = bool> [NeFuture<Self, S>]
         where
-            Self: Sized + Stream,
+            Self: Sized,
             S: Sized + Stream,
             <Self as Stream>::Item: PartialEq<S::Item>,
         {
@@ -2025,11 +2289,11 @@ extension_trait! {
         }
 
         #[doc = r#"
-            Sums the elements of an iterator.
+            Sums the elements of a stream.
 
             Takes each element, adds them together, and returns the result.
 
-            An empty iterator returns the zero value of the type.
+            An empty streams returns the zero value of the type.
 
             # Panics
 
@@ -2062,15 +2326,15 @@ extension_trait! {
         ) -> impl Future<Output = S> + 'a [Pin<Box<dyn Future<Output = S> + 'a>>]
         where
             Self: Sized + Stream<Item = S> + 'a,
-            S: Sum,
+            S: Sum<Self::Item>,
         {
             Sum::sum(self)
         }
 
         #[doc = r#"
-            Iterates over the entire iterator, multiplying all the elements
+            Multiplies all elements of the stream.
 
-            An empty iterator returns the one value of the type.
+            An empty stream returns the one value of the type.
 
             # Panics
 
