@@ -1,10 +1,10 @@
 use std::cmp::Ordering;
+use std::future::Future;
 use std::pin::Pin;
 
 use pin_project_lite::pin_project;
 
 use super::fuse::Fuse;
-use crate::future::Future;
 use crate::prelude::*;
 use crate::stream::Stream;
 use crate::task::{Context, Poll};
@@ -26,7 +26,7 @@ pin_project! {
 
 impl<L: Stream, R: Stream> PartialCmpFuture<L, R> {
     pub(super) fn new(l: L, r: R) -> Self {
-        PartialCmpFuture {
+        Self {
             l: l.fuse(),
             r: r.fuse(),
             l_cache: None,
