@@ -11,7 +11,7 @@ use std::sync::atomic::{self, AtomicUsize, Ordering};
 use std::sync::Arc;
 use std::task::{Context, Poll};
 
-use crossbeam_utils::{Backoff, CachePadded};
+use crossbeam_utils::Backoff;
 
 use crate::stream::Stream;
 use crate::sync::WakerSet;
@@ -71,6 +71,11 @@ pub fn channel<T>(cap: usize) -> (Sender<T>, Receiver<T>) {
 
 /// The sending side of a channel.
 ///
+/// This struct is created by the [`channel`] function. See its
+/// documentation for more.
+///
+/// [`channel`]: fn.channel.html
+///
 /// # Examples
 ///
 /// ```
@@ -298,8 +303,11 @@ impl<T> fmt::Debug for Sender<T> {
 
 /// The receiving side of a channel.
 ///
-/// This type implements the [`Stream`] trait, which means it can act as an asynchronous iterator.
+/// This type receives messages by calling `recv`. But it also implements the [`Stream`] trait,
+/// which means it can act as an asynchronous iterator. This struct is created by the [`channel`]
+/// function. See its documentation for more.
 ///
+/// [`channel`]: fn.channel.html
 /// [`Stream`]: ../stream/trait.Stream.html
 ///
 /// # Examples
@@ -577,7 +585,7 @@ struct Channel<T> {
     /// represent the lap. The mark bit in the head is always zero.
     ///
     /// Messages are popped from the head of the channel.
-    head: CachePadded<AtomicUsize>,
+    head: AtomicUsize,
 
     /// The tail of the channel.
     ///
@@ -586,7 +594,7 @@ struct Channel<T> {
     /// represent the lap. The mark bit indicates that the channel is disconnected.
     ///
     /// Messages are pushed into the tail of the channel.
-    tail: CachePadded<AtomicUsize>,
+    tail: AtomicUsize,
 
     /// The buffer holding slots.
     buffer: *mut Slot<T>,
@@ -660,8 +668,8 @@ impl<T> Channel<T> {
             cap,
             one_lap,
             mark_bit,
-            head: CachePadded::new(AtomicUsize::new(head)),
-            tail: CachePadded::new(AtomicUsize::new(tail)),
+            head: AtomicUsize::new(head),
+            tail: AtomicUsize::new(tail),
             send_wakers: WakerSet::new(),
             recv_wakers: WakerSet::new(),
             stream_wakers: WakerSet::new(),
